@@ -8,7 +8,7 @@ import copy
 import re
 import scipy.optimize as spo
 import itertools
-
+import sys
 
 atom_lab_num = {"H": 1, "He": 2, "Li": 3, "Be": 4, "B": 5, "C": 6, "N": 7,
                 "O": 8, "F": 9, "Ne": 10, "Na": 11, "Mg": 12, "Al": 13,
@@ -51,18 +51,18 @@ def load_xyz(f_name: str, atomic_numbers: bool = False):
 
     Parameters
     ----------
-        f_name : str
-            File name
-        atomic_numbers : bool, optional
-            If true, will read xyz file with atomic numbers and convert
-            to labels
+    f_name : str
+        File name
+    atomic_numbers : bool, optional
+        If true, will read xyz file with atomic numbers and convert
+        to labels
 
     Returns
     -------
-        _labels : list
-            atomic labels
-        _coords : list
-            list of 3 element lists containing xyz coordinates of each atom
+    _labels : list
+        atomic labels
+    _coords : np.ndarray
+        (n_atoms,3) array containing xyz coordinates of each atom
     """
 
     if atomic_numbers:
@@ -74,7 +74,7 @@ def load_xyz(f_name: str, atomic_numbers: bool = False):
     # Set labels as capitals
     _labels = [lab.capitalize() for lab in _labels]
 
-    _coords = list(np.loadtxt(f_name, skiprows=2, usecols=(1, 2, 3)))
+    _coords = np.loadtxt(f_name, skiprows=2, usecols=(1, 2, 3))
 
     return _labels, _coords
 
@@ -87,25 +87,25 @@ def save_xyz(f_name: str, labels: list, coords: list,
 
     Parameters
     ----------
-        f_name : str
-            File name
-        labels : list
-            atomic labels
-        coords : list
-            list of 3 element lists containing xyz coordinates of each atom
-        with_numbers : bool, optional
-            If True, add/overwrite numbers to labels before printing
-        verbose : bool, optional
-            Print information on filename to screen
-        mask : list, optional
-            n_atom list of 0 (exclude) and 1 (include) indicating which
-            atoms to print
-        atomic_numbers : bool, optional
-            If true, will save xyz file with atomic numbers
+    f_name : str
+        File name
+    labels : list
+        atomic labels
+    coords : list
+        list of 3 element lists containing xyz coordinates of each atom
+    with_numbers : bool, optional
+        If True, add/overwrite numbers to labels before printing
+    verbose : bool, optional
+        Print information on filename to screen
+    mask : list, optional
+        n_atom list of 0 (exclude) and 1 (include) indicating which
+        atoms to print
+    atomic_numbers : bool, optional
+        If true, will save xyz file with atomic numbers
 
     Returns
     -------
-        None
+    None
     """
 
     # Option to have numbers added
@@ -151,13 +151,13 @@ def remove_numbers(labels: list):
 
     Parameters
     ----------
-        labels : list
-            atomic labels
+    labels : list
+        atomic labels
 
     Returns
     -------
-        labels_nn : list
-            atomic labels without numbers
+    list
+        atomic labels without numbers
     """
 
     labels_nn = []
@@ -178,17 +178,17 @@ def add_numbers(labels: list, style: str = 'per_element'):
 
     Parameters
     ----------
-        labels : list
-            atomic labels
-        style : str, optional
-            {'per_element', 'sequential'}
-                'per_element' : Number by element e.g. Dy1, Dy2, N1, N2, etc.
-                'sequential' : Number the atoms 1->N regardless of element
+    labels : list
+        atomic labels
+    style : str, optional
+        {'per_element', 'sequential'}
+            'per_element' : Number by element e.g. Dy1, Dy2, N1, N2, etc.
+            'sequential' : Number the atoms 1->N regardless of element
 
     Returns
     -------
-        labels_wn : list
-            atomic labels with numbers
+    list
+        atomic labels with numbers
     """
 
     # remove numbers just in case
@@ -222,13 +222,13 @@ def count_n_atoms(form_str: str):
 
     Parameters
     ----------
-        form_str : str
-            chemical formula string
+    form_str : str
+        chemical formula string
 
     Returns
     -------
-        n_atoms : int
-            number of atoms in chemical formula
+    int
+        number of atoms in chemical formula
     """
 
     form_dict = formstr_to_formdict(form_str)
@@ -245,15 +245,15 @@ def index_elements(labels: list, shift: int = 0):
 
     Parameters
     ----------
-        labels : list
-            atomic labels
-        shift : int, optional
-            additive shift to apply to all indices
+    labels : list
+        atomic labels
+    shift : int, optional
+        additive shift to apply to all indices
 
     Returns
     -------
-        ele_index : dict
-            dictionary of element (keys) and indices (values)
+    dict
+        element (keys) and indices (values)
     """
 
     labels_nn = remove_numbers(labels)
@@ -275,12 +275,12 @@ def count_elements(labels: list):
 
     Parameters
     ----------
-        labels : list
-            atomic labels
+    labels : list
+        atomic labels
     Returns
     -------
-        ele_count : dict
-            dictionary of elements (keys) and counts (vals)
+    dict
+        dictionary of elements (keys) and counts (vals)
     """
 
     labels_nn = remove_numbers(labels)
@@ -298,16 +298,16 @@ def count_elements(labels: list):
 
 def get_formula(labels: list):
     """
-    Returns empirical formula in alphabetical order given a list of labels
+    Generates empirical formula in alphabetical order given a list of labels
 
     Parameters
     ----------
-        labels : list
-            atomic labels
+    labels : list
+        atomic labels
     Returns
     -------
-        formula : str
-            Empirical formula in alphabetical order
+    str
+        Empirical formula in alphabetical order
     """
 
     formdict = count_elements(labels)
@@ -323,13 +323,13 @@ def formstr_to_formdict(form_str: str):
 
     Parameters
     ----------
-        form_string : str
-            Chemical formula as string
+    form_string : str
+        Chemical formula as string
 
     Returns
     -------
-        form_dict : dict
-            dictionary of {atomic label:quantity} pairs
+    dict
+        dictionary of {atomic label:quantity} pairs
     """
 
     form_dict = {}
@@ -350,15 +350,15 @@ def formdict_to_formstr(form_dict: dict, include_one: bool = False):
 
     Parameters
     ----------
-        form_dict : dict
-            dictionary of {atomic label:quantity} pairs
-        include_one : bool, optional
-            Include 1 in final chemical formula e.g. C1H4
+    form_dict : dict
+        dictionary of {atomic label:quantity} pairs
+    include_one : bool, optional
+        Include 1 in final chemical formula e.g. C1H4
 
     Returns
     -------
-        form_string : str
-            Chemical formula as string in alphabetical order
+    str
+        Chemical formula as string in alphabetical order
     """
 
     # Formula labels and quantities as separate lists with same order
@@ -396,19 +396,19 @@ def contains_metal(form_string: str):
 
     Parameters
     ----------
-        form_string : str
-            Chemical formula as string
+    form_string : str
+        Chemical formula as string
 
     Returns
     -------
-        metal_found : int
-            Combined atomic labels
+    bool
+        True if metal found, else False
     """
-    metal_found = 0
+    metal_found = False
 
     for metal in metals:
         if metal in form_string:
-            metal_found = 1
+            metal_found = True
             break
 
     return metal_found
@@ -421,21 +421,21 @@ def combine_xyz(labels_1: list, labels_2: list,
 
     Parameters
     ----------
-        labels_1 : list
-            Atomic labels
-        coords_1 : list
-            list of lists of xyz coordinates of each atom
-        labels_2 : list
-            Atomic labels
-        coords_2 : list
-            list of lists of xyz coordinates of each atom
+    labels_1 : list
+        Atomic labels
+    coords_1 : list
+        list of lists of xyz coordinates of each atom
+    labels_2 : list
+        Atomic labels
+    coords_2 : list
+        list of lists of xyz coordinates of each atom
 
     Returns
     -------
-        labels : list
-            Combined atomic labels
-        coords : list
-            Combined list of lists of xyz coordinates of each atom
+    list
+        Combined atomic labels
+    list
+        Combined list of lists of xyz coordinates of each atom
     """
 
     # Concatenate labels lists
@@ -453,17 +453,17 @@ def get_neighborlist(labels: list, coords: list, adjust_cutoff: dict = {}):
 
     Parameters
     ----------
-        labels : list
-            Atomic labels
-        coords : list
-            list of lists of xyz coordinates of each atom
-        adjust_cutoff : dict, optional
-            dictionary of atoms (keys) and new cutoffs (values)
+    labels : list
+        Atomic labels
+    coords : list
+        list of lists of xyz coordinates of each atom
+    adjust_cutoff : dict, optional
+        dictionary of atoms (keys) and new cutoffs (values)
 
     Returns
     -------
-        neigh_list : ASE neighbourlist object
-            Neighbourlist for system
+    ASE neighbourlist object
+        Neighbourlist for system
     """
 
     # Remove labels if present
@@ -500,17 +500,17 @@ def get_adjacency(labels: list, coords: list, adjust_cutoff: dict = {},
 
     Parameters
     ----------
-        labels : list
-            Atomic labels
-        coords : list
-            list of lists of xyz coordinates of each atom
-        adjust_cutoff : dict, optional
-            dictionary of atoms (keys) and new cutoffs (values)
+    labels : list
+        Atomic labels
+    coords : list
+        list of lists of xyz coordinates of each atom
+    adjust_cutoff : dict, optional
+        dictionary of atoms (keys) and new cutoffs (values)
 
     Returns
     -------
-        adjacency : np.array
-            Adjacency matrix with same order as labels/coords
+    np.array
+        Adjacency matrix with same order as labels/coords
     """
 
     # Remove labels if present
@@ -541,29 +541,27 @@ def get_bonds(labels: list, coords: list, neigh_list=None,
 
     Parameters
     ----------
-        labels : list
-            Atomic labels
-        coords : list
-            list of lists of xyz coordinates of each atom
-
-    Keyword arguments:
-        neigh_list : ASE neighbourlist object, optional
-            neighbourlist of system
-        f_name : str, optional
-            filename to save bond list to
-        save : bool, optional
-            Save bond list to file
-        verbose : bool, optional
-            Print number of bonds to screen
-        style : str, optional
-            {'index','label'}
-                indices : Bond list contains atom number
-                labels  : Bond list contains atom label
+    labels : list
+        Atomic labels
+    coords : list
+        list of lists of xyz coordinates of each atom
+    neigh_list : ASE neighbourlist object, optional
+        neighbourlist of system
+    f_name : str, optional
+        filename to save bond list to
+    save : bool, optional
+        Save bond list to file
+    verbose : bool, optional
+        Print number of bonds to screen
+    style : str, optional
+        {'indices','labels'}
+            indices : Bond list contains atom number
+            labels  : Bond list contains atom label
 
     Returns
     -------
-        bonds : list
-            list of unique bonds (atom pairs)
+    list
+        list of lists of unique bonds (atom pairs)
     """
 
     # Remove labels if present
@@ -606,6 +604,8 @@ def get_bonds(labels: list, coords: list, neigh_list=None,
     elif style == 'labels':
         bonds = [[labels[atom1], labels[atom2]] for atom1, atom2 in bonds]
         save_fmt = "%s"
+    else:
+        sys.exit("Unknown save style specified")
 
     # Save bond list to file
     if save:
@@ -629,27 +629,27 @@ def get_angles(labels: list, coords: list, neigh_list=None,
 
     Parameters
     ----------
-        labels : list
-            Atomic labels
-        coords : list
-            list of lists of xyz coordinates of each atom
-        neigh_list : ASE neighbourlist object, optional
-            neighbourlist of system
-        f_name : str, optional
-            filename to save angle list to
-        save : bool, optional
-            Save angle list to file
-        verbose : bool, optional
-            Print number of angles to screen
-        style : str, optional
-            {'index','label'}
-                indices : Angle list contains atom number
-                labels  : Angle list contains atom label
+    labels : list
+        Atomic labels
+    coords : list
+        list of lists of xyz coordinates of each atom
+    neigh_list : ASE neighbourlist object, optional
+        neighbourlist of system
+    f_name : str, optional
+        filename to save angle list to
+    save : bool, optional
+        Save angle list to file
+    verbose : bool, optional
+        Print number of angles to screen
+    style : str, optional
+        {'indices','labels'}
+            indices : Angle list contains atom number
+            labels  : Angle list contains atom label
 
     Returns
     -------
-        angles : list
-            list of unique angles (atom trios)
+    list
+        list of lists of unique angles (atom trios)
     """
 
     # Remove labels if present
@@ -693,6 +693,8 @@ def get_angles(labels: list, coords: list, neigh_list=None,
         angles = [[labels[atom1], labels[atom2], labels[atom3]]
                   for atom1, atom2, atom3 in angles]
         save_fmt = "%s"
+    else:
+        sys.exit("Unknown save style specified")
 
     # Save angle list to file
     if save:
@@ -716,27 +718,27 @@ def get_dihedrals(labels: list, coords: list, neigh_list=None,
 
     Parameters
     ----------
-        labels : list
-            Atomic labels
-        coords : list
-            list of lists of xyz coordinates of each atom
-        neigh_list : ASE neighbourlist object, optional
-            neighbourlist of system
-        f_name : str, optional
-            filename to save angle list to
-        save : bool, optional
-            Save angle list to file
-        verbose : bool, optional
-            Print number of dihedrals to screen
-        style : str, optional
-            {'index','label'}
-                indices : Dihedral list contains atom number
-                labels  : Dihedral list contains atom label
+    labels : list
+        Atomic labels
+    coords : list
+        list of lists of xyz coordinates of each atom
+    neigh_list : ASE neighbourlist object, optional
+        neighbourlist of system
+    f_name : str, optional
+        filename to save angle list to
+    save : bool, optional
+        Save angle list to file
+    verbose : bool, optional
+        Print number of dihedrals to screen
+    style : str, optional
+        {'indices','labels'}
+            indices : Dihedral list contains atom number
+            labels  : Dihedral list contains atom label
 
     Returns
     -------
-        dihedrals : list
-            list of unique dihedrals (atom quads)
+    list
+        list of lists of unique dihedrals (atom quads)
     """
 
     # Remove labels if present
@@ -787,6 +789,8 @@ def get_dihedrals(labels: list, coords: list, neigh_list=None,
                      for atom1, atom2, atom3, atom4 in dihedrals
                     ]
         save_fmt = "%s"
+    else:
+        sys.exit("Unknown save style specified")
 
     # Save dihedral list to file
     if save:
@@ -806,13 +810,13 @@ def lab_to_num(labels: list):
 
     Parameters
     ----------
-        labels : list
-            Atomic labels
+    labels : list
+        Atomic labels
 
     Returns
     -------
-        numbers : list
-            Atomic numbers
+    list
+        Atomic numbers
     '''
 
     labels_nn = remove_numbers(labels)
@@ -828,15 +832,15 @@ def num_to_lab(numbers: list, numbered: bool = True):
 
     Parameters
     ----------
-        numbers : list
-            Atomic numbers
-        numbered : bool, optional
-            Add indexing number to end of atomic labels
+    numbers : list
+        Atomic numbers
+    numbered : bool, optional
+        Add indexing number to end of atomic labels
 
     Returns
     -------
-        labels : list
-            Atomic labels
+    list
+        Atomic labels
     '''
 
     labels = [atom_num_lab[num] for num in numbers]
@@ -855,13 +859,13 @@ def reflect_coords(coords: list):
 
     Parameters
     ----------
-        coords : list
-            list of lists of xyz coordinates of each atom
+    coords : list
+        list of lists of xyz coordinates of each atom
 
     Returns
     -------
-        coords : list
-            list of lists of xyz coordinates of each atom
+    list
+        list of lists of xyz coordinates of each atom
 
     """
 
@@ -872,7 +876,6 @@ def reflect_coords(coords: list):
 
     # Set up transformation matrix
     # https://en.wikipedia.org/wiki/Transformation_matrix#Reflection_2
-    # Can reflect in any plane but xy has been used
     trans_mat = np.zeros([3, 3])
 
     trans_mat[0, 0] = 1. - 2.*normal[0]**2.
@@ -904,44 +907,43 @@ def remove_broken(labels: list, coords: list, formulae: list,
 
     Parameters
     ----------
-        labels : list
-            list of atomic labels
-        coords : list
-            list of lists of xyz coordinates of each atom
-        formulae : list
-            list of chemical formulae stored as dictionaries with atomic
-            symbol (key) count (val) pairs
-        adjust_cutoff : dict, optional
-            dictionary of atoms (keys) and new cutoffs (values)
-        verbose : bool, optional
-            print molecule count to screen
-        save : bool, optional
-            Save molecules and incomplete fragments to separate xyz files
-        frag_f_name : str, optional
-            Name for xyz file containing fragmented structures
-        clean_f_name : str, optional
-            Name for xyz file containing full molecules
-        mask : list, optional
-            list of 0 (exclude) and 1 (include) for each element
-                - if used, final lists will exclude masked elements
-        skip : list, optional
-            List of atomic indices which shall not be visited when tracing
-            bonding network
+    labels : list
+        list of atomic labels
+    coords : list
+        list of lists of xyz coordinates of each atom
+    formulae : list
+        list of chemical formulae stored as dictionaries with atomic
+        symbol (key) count (val) pairs
+    adjust_cutoff : dict, optional
+        dictionary of atoms (keys) and new cutoffs (values)
+    verbose : bool, optional
+        print molecule count to screen
+    save : bool, optional
+        Save molecules and incomplete fragments to separate xyz files
+    frag_f_name : str, optional
+        Name for xyz file containing fragmented structures
+    clean_f_name : str, optional
+        Name for xyz file containing full molecules
+    mask : list, optional
+        list of 0 (exclude) and 1 (include) for each element
+            - if used, final lists will exclude masked elements
+    skip : list, optional
+        List of atomic indices which shall not be visited when tracing
+        bonding network
     Returns
     -------
-        labels_clean : list
-            list of atomic labels for full molecules
-        coords_clean (list)  :
-            list of lists of xyz coordinates of each atom for full molecules
-        labels_fragments : list
-            list of atomic labels for fragments
-        coords_fragments : list
-            list of lists of xyz coordinates of each atom for fragments
-        mol_indices     : dict
-            dictionary containing indices of complete molecules -
-                keys = molecular formula,
-                vals = list of lists of atomic indices
-                        for each atom
+    list
+        atomic labels for full molecules
+    list
+        list of lists of xyz coordinates of each atom for full molecules
+    list
+        atomic labels for fragments
+    list
+        list of lists of xyz coordinates of each atom for fragments
+    dict
+        keys = molecular formula,
+        vals = list of lists of atomic indices
+                for each atom
     """
 
     # Remove label numbers if present
@@ -1073,7 +1075,7 @@ def remove_broken(labels: list, coords: list, formulae: list,
 
     # Reorder inds_clean so that metal containing molecules are at the start
     metals_top_order = np.argsort(
-        [not contains_metal(formula) for formula in form_clean]
+        [not int(contains_metal(formula)) for formula in form_clean]
         )
     inds_clean = _reorder_list(inds_clean, metals_top_order)
 
@@ -1116,18 +1118,19 @@ def _mask_list(_list: list, mask: list, opp_mask: bool = False):
 
     Parameters
     ----------
-        _list : list
-            list to mask
-        mask : list
-            list of 0 (exclude) and 1 (include) for each element
+    _list : list
+        list to mask
+    mask : list
+        list of 0 (exclude) and 1 (include) for each element
 
-        opp_mask : bool, optional
-            Apply mask in opposite fashion:
-                0 (include) and 1 (exclude)
+    opp_mask : bool, optional
+        Apply mask in opposite fashion:
+            0 (include) and 1 (exclude)
 
     Returns
     -------
-        _list_masked : float Masked list
+    float
+        Masked list
     """
 
     # Flip mask other way around if requested
@@ -1148,15 +1151,15 @@ def _reorder_list(_list: list, order: list):
 
     Parameters
     ----------
-        _list : list
-            list to reorder
-        order : list
-            New order for list
+    _list : list
+        list to reorder
+    order : list
+        New order for list
 
     Returns
     -------
-        _list_reordered : float
-            Reordered list
+    list
+        Reordered list
     """
 
     # Apply mask to list
@@ -1172,16 +1175,16 @@ def _calculate_rmsd(coords_1: list, coords_2: list):
     Where deviations are defined as norm([x1,y1,z1]-[x2,y2,z2])
 
     Parameters
-    ----------
-        coords_1 : list
-            list of lists of xyz coordinates of each atom
-        coords_2 : list
-            list of lists of xyz coordinates of each atom
+----------
+    coords_1 : list
+        list of lists of xyz coordinates of each atom
+    coords_2 : list
+        list of lists of xyz coordinates of each atom
 
     Returns
     -------
-        rmsd : float
-            Root mean square of norms of deviation between two structures
+    float
+        Root mean square of norms of deviation between two structures
     """
 
     # Check there are the same number of coordinates
@@ -1215,24 +1218,24 @@ def calculate_rmsd(coords_1: list, coords_2: list, mask_1: list = [],
 
     Parameters
     ----------
-        coords_1 : list
-            list of lists of xyz coordinates of each atom
-        coords_2 : list
-            list of lists of xyz coordinates of each atom
+    coords_1 : list
+        list of lists of xyz coordinates of each atom
+    coords_2 : list
+        list of lists of xyz coordinates of each atom
 
-        mask_1 : list
-            list of 0 (exclude) and 1 (include) for each element in coords_1
-        mask_2 : list
-            list of 0 (exclude) and 1 (include) for each element in coords_2
-        order_1 : list
-            list of new indices for coords_1 - applied BEFORE masking
-        order_2 : list
-            list of new indices for coords_2 - applied BEFORE masking
+    mask_1 : list
+        list of 0 (exclude) and 1 (include) for each element in coords_1
+    mask_2 : list
+        list of 0 (exclude) and 1 (include) for each element in coords_2
+    order_1 : list
+        list of new indices for coords_1 - applied BEFORE masking
+    order_2 : list
+        list of new indices for coords_2 - applied BEFORE masking
 
     Returns
     -------
-        rmsd : float
-            Root mean square of norms of deviation between two structures
+    float
+        Root mean square of norms of deviation between two structures
     """
 
     # Set up new ordering
@@ -1279,19 +1282,20 @@ def rotate_coords(coords: list, alpha: float, beta: float, gamma: float):
 
     Parameters
     ----------
-        coords_1 : list
-            list of lists of xyz coordinates of each atom
-        alpha : float
-            alpha angle in radians
-        beta : float
-            beta  angle in radians
-        gamma : float
-            gamma angle in radians
+    coords_1 : list
+        list of lists of xyz coordinates of each atom
+    alpha : float
+        alpha angle in radians
+    beta : float
+        beta  angle in radians
+    gamma : float
+        gamma angle in radians
 
     Returns
     -------
-        rot_coords : list
-            list of lists of xyz coordinates of each atom after rotation
+    list
+        list of lists of xyz coordinates of each atom after rotation
+        in same order as input coordinates
     """
 
     R = np.zeros([3, 3])
@@ -1333,24 +1337,23 @@ def minimise_rmsd(coords_1: list, coords_2: list, mask_1: list = [],
 
     Parameters
     ----------
-        coords_1 : list
-            list of lists of xyz coordinates of each atom
-        coords_2 : list
-            list of lists of xyz coordinates of each atom
-
-        mask_1 (list)  :
-            list of 0 (exclude) and 1 (include) for each element in coords_1
-        mask_2 (list)  :
-            list of 0 (exclude) and 1 (include) for each element in coords_2
-        order_1 : list
-            list of new indices for coords_1 - applied BEFORE masking
-        order_2 : list
-            list of new indices for coords_2 - applied BEFORE masking
+    coords_1 : list
+        list of lists of xyz coordinates of each atom
+    coords_2 : list
+        list of lists of xyz coordinates of each atom
+    mask_1 : list
+        list of 0 (exclude) and 1 (include) for each element in coords_1
+    mask_2 : list
+        list of 0 (exclude) and 1 (include) for each element in coords_2
+    order_1 : list
+        list of new indices for coords_1 - applied BEFORE masking
+    order_2 : list
+        list of new indices for coords_2 - applied BEFORE masking
 
     Returns
     -------
-        rmsd : float
-            Root mean square of norms of deviation between two structures
+    float
+        Root mean square of norms of deviation between two structures
     """
 
     # Set up new ordering
@@ -1403,17 +1406,18 @@ def _rotate_and_rmsd(angs: list, coords_1: list, coords_2: list):
 
     Parameters
     ----------
-        coords_1 : list
-            list of lists of xyz coordinates of each atom of first system
-        coords_2 : list
-            list of lists of xyz coordinates of each atom of second system
-        angs : list
-            alpha, beta, gamma in radians
+    coords_1 : list
+        list of lists of xyz coordinates of each atom of first system
+    coords_2 : list
+        list of lists of xyz coordinates of each atom of second system
+    angs : list
+        alpha, beta, gamma in radians
 
     Returns
     -------
-        rot_coords : list
-            list of lists of xyz coordinates of each atom after rotation
+    list
+        list of lists of xyz coordinates of each atom after rotation
+        in same order as input coordinates
     """
 
     # Rotate coordinates of first system
